@@ -4,7 +4,6 @@ from .builders import (
 )
 from .comparators import (
     TypeHintComparator,
-    is_aggregate_type,
     is_model_subclass,
     is_model_type,
     is_type_subclass,
@@ -17,11 +16,6 @@ from .generics import (
     GenericTypeProjector,
     unpack_typevar,
 )
-from .model_refs import (
-    ModelRef,
-    ModelRefExtractor,
-    ModelRefInjector,
-)
 from .model_types import (
     ModelType,
 )
