@@ -1,10 +1,3 @@
-"""
-Copyright (C) 2021 Clariteia SL
-
-This file is part of minos framework.
-
-Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
-"""
 from __future__ import (
     annotations,
 )
@@ -15,7 +8,6 @@ from abc import (
 )
 from typing import (
     Any,
-    NoReturn,
 )
 
 from .setup import (
@@ -27,7 +19,7 @@ class MinosBroker(ABC, MinosSetup):
     """Base Broker class."""
 
     @abstractmethod
-    async def send(self, data: Any, **kwargs) -> NoReturn:
+    async def send(self, data: Any, **kwargs) -> None:
         """Send a list of ``Aggregate`` instances.
 
         :param data: The data to be send.
